#! /usr/bin/python
#
# Copyright 2014 Canonical Ltd.  This software is licensed under the
# GNU Affero General Public License version 3 (see the file LICENSE).

"""Get supported suites from Launchpad."""

from __future__ import print_function

from optparse import OptionValueError

from scripts.base import (
    ScriptBase,
    ScriptFailure,
    )


class GetSupportedSeries(ScriptBase):
    """Main class for getting supported series."""

    def add_my_options(self):
        """Add a 'distribution' context option."""
        self.parser.add_option(
            "-d", "--distribution", dest="distribution",
            help="Context distribution name.")

    def setUp(self):
        """Process command-line options."""
        self.options.launchpad = self.login()

        if self.options.distribution is None:
            raise OptionValueError("Specify a distribution.")

        try:
            self.distribution = self.options.launchpad.distributions[
                self.options.distribution]
        except KeyError:
            raise OptionValueError(
                "Distribution '%s' not found." % self.options.distribution)

    def getSupportedSeries(self):
        self.setUp()

        supported_series = []
        unsupported_statuses = ('Future', 'Obsolete')
        for series in self.distribution.series:
            if series.status not in unsupported_statuses:
                supported_series.append(series.name)

        if not supported_series:
            raise ScriptFailure(
                "There is no supported distroseries for %s." %
                self.distribution.name)

        return supported_series

    def main(self):
        print(" ".join(self.getSupportedSeries()))
